# InstanceClassifier

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**brand_name** | **str** |  | [optional] 
**commit_message** | **str** |  | [optional] 
**custom** | **bool** |  | [optional] 
**default_incident_type** | **str** |  | [optional] 
**feed** | **bool** |  | [optional] 
**from_server_version** | [**Version**](Version.md) |  | [optional] 
**id** | **str** |  | [optional] 
**incident_samples** | [**Incidents**](Incidents.md) |  | [optional] 
**indicator_samples** | [**FeedIndicators**](FeedIndicators.md) |  | [optional] 
**instance_id** | **str** |  | [optional] 
**instance_name** | **str** |  | [optional] 
**is_default** | **bool** |  | [optional] 
**item_version** | [**Version**](Version.md) |  | [optional] 
**key_type_map** | **dict(str, str)** |  | [optional] 
**mapping** | [**dict(str, Mapper)**](Mapper.md) |  | [optional] 
**modified** | **datetime** |  | [optional] 
**pack_id** | **str** |  | [optional] 
**primary_term** | **int** |  | [optional] 
**propagation_labels** | **list[str]** |  | [optional] 
**sequence_number** | **int** |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


